@@ -10,6 +10,7 @@ from typing import List, NamedTuple
 from bleak import BleakClient
 from bleak import BleakScanner
 from bleak.backends.device import BLEDevice
+from bleak.uuids import normalize_uuid_16
 
 
 class Aranet4Error(Exception):
@@ -30,23 +31,42 @@ class Param(IntEnum):
     RADIATION_DOSE_INTEGRAL = 9
     RADON_CONCENTRATION = 10
 
-class Status(IntEnum):
+class Color(IntEnum):
     """Enum for the different status colors"""
 
-    NONE = 0
+    ERROR = 0
     GREEN = 1
-    AMBER = 2
+    YELLOW = 2
     RED = 3
-    BLUE = 4
+
+class Status(IntEnum):
+    """Enum for the different status alerts"""
+
+    OFF = 0
+    UNDER = 1
+    OVER = 2
+    DASH = 3
 
 class AranetType(IntEnum):
     """Enum for the different Aranet devices"""
+    
     ARANET4 = 0
     ARANET2 = 1
     ARANET_RADIATION = 2
     ARANET_RADON = 3
     UNKNOWN = 255
 
+    @property
+    def model(self):
+        description = {
+            AranetType.ARANET4: "Aranet4",
+            AranetType.ARANET2: "Aranet2",
+            AranetType.ARANET_RADIATION: "Aranet Radiation",
+            AranetType.ARANET_RADON: "Aranet Radon Plus",
+            AranetType.UNKNOWN: "Unknown Aranet Device"
+        }
+        return description.get(self, "Unknown Aranet Device")
+
 @dataclass
 class Aranet4HistoryDelegate:
     """
@@ -76,9 +96,7 @@ class Aranet4HistoryDelegate:
 
         if self.param != data_type:
             (
-                "ERROR: invalid parameter. Got {:02X}, expected {:02X}".format(
-                    data_type, self.param
-                )
+                print(f"ERROR: invalid parameter. Got {data_type:02X}, expected {self.param:02X}")
             )
             return
         pattern = "<B" if data_type == Param.HUMIDITY else "<H"
@@ -119,8 +137,8 @@ class CurrentReading:
 
     battery: int = -1
     status: int = -1
-    status_t: int = -1
-    status_h: int = -1
+    status_temperature: int = -1
+    status_humidity: int = -1
     interval: int = -1
     ago: int = -1
     stored: int = -1
@@ -146,27 +164,29 @@ class CurrentReading:
             ret += f"  Pressure:       {self.pressure:.01f} hPa\n"
             ret += f"  Battery:        {self.battery} %\n"
             ret += f"  Status Display: {self.status.name}\n"
-            ret += f"  Age:            {self.ago}/{self.interval}\n"
+            ret += f"  Age:            {self.ago}/{self.interval} s\n"
         elif self.type == AranetType.ARANET2:
             ret += f"  Temperature:    {self.temperature:.01f} \u00b0C\n"
             ret += f"  Humidity:       {self.humidity} %\n"
             ret += f"  Battery:        {self.battery} %\n"
-            ret += f"  Status Temp.:   {self.status_t.name}\n"
-            ret += f"  Status Humid.:  {self.status_h.name}\n"
-            ret += f"  Age:            {self.ago}/{self.interval}\n"
+            ret += f"  Status Temp.:   {self.status_temperature.name}\n"
+            ret += f"  Status Humid.:  {self.status_humidity.name}\n"
+            ret += f"  Age:            {self.ago}/{self.interval} s\n"
         elif self.type == AranetType.ARANET_RADIATION:
             m = math.floor(self.radiation_duration / 60 % 60)
             h = math.floor(self.radiation_duration / 3600 % 24)
             d = math.floor(self.radiation_duration / 86400)
 
             dose_duration = str(m) + "m"
-            if h > 0: dose_duration = str(h) + "h " + dose_duration
-            if d > 0: dose_duration = str(d) + "d " + dose_duration
+            if h > 0:
+                dose_duration = str(h) + "h " + dose_duration
+            if d > 0:
+                dose_duration = str(d) + "d " + dose_duration
 
             ret += f"  Dose rate:      {self.radiation_rate/1000:.02f} uSv/h\n"
             ret += f"  Dose total:     {self.radiation_total/1000000:.04f} mSv/{dose_duration}\n"
             ret += f"  Battery:        {self.battery} %\n"
-            ret += f"  Age:            {self.ago}/{self.interval}\n"
+            ret += f"  Age:            {self.ago}/{self.interval} s\n"
         elif self.type == AranetType.ARANET_RADON:
             ret += f"  Radon Conc.:    {self.radon_concentration} Bq/m3\n"
             ret += f"  Temperature:    {self.temperature:.01f} \u00b0C\n"
@@ -174,10 +194,10 @@ class CurrentReading:
             ret += f"  Pressure:       {self.pressure:.01f} hPa\n"
             ret += f"  Battery:        {self.battery} %\n"
             ret += f"  Status Display: {self.status.name}\n"
-            ret += f"  Age:            {self.ago}/{self.interval}\n"
+            ret += f"  Age:            {self.ago}/{self.interval} s\n"
 
         else:
-            ret += f"  Unknown device type\n"
+            ret += "  Unknown device type\n"
 
         return ret
 
@@ -223,7 +243,7 @@ class CurrentReading:
         self.pressure = self._set(Param.PRESSURE, value[2])
         self.humidity = self._set(Param.HUMIDITY, value[3])
         self.battery = value[4]
-        self.status = Status(value[5])
+        self.status = Color(value[5])
         # If extended data list
         if len(value) > 6:
             self.interval = value[6]
@@ -237,13 +257,15 @@ class CurrentReading:
             self.temperature = self._set(Param.TEMPERATURE, value[4])
             self.humidity = self._set(Param.HUMIDITY2, value[5])
             self.battery = value[3]
-            self.status_h, self.status_t = self._decode_status_flags(value[6])
+            self.status_humidity = Status(value[6] & 0b0011)
+            self.status_temperature = Status((value[6] & 0b1100) >> 2)
             self.interval = value[1]
             self.ago = value[2]
         else:
             self.temperature = self._set(Param.TEMPERATURE, value[1])
             self.humidity = self._set(Param.HUMIDITY2, value[3])
-            self.status_h, self.status_t = self._decode_status_flags(value[6])
+            self.status_humidity = Status(value[6] & 0b0011)
+            self.status_temperature = Status((value[6] & 0b1100) >> 2)
             self.battery = value[5]
             self.interval = value[7]
             self.ago = value[8]
@@ -277,7 +299,7 @@ class CurrentReading:
             self.pressure = self._set(Param.PRESSURE, value[5])
             self.humidity = self._set(Param.HUMIDITY2, value[6])
             self.radon_concentration = self._set(Param.RADON_CONCENTRATION, value[7])
-            self.status = Status(value[8])
+            self.status = Color(value[8])
             self.radon_concentration_avg_24h = self._parse_avg_radon(value[9], value[10])["value"]
             self.radon_concentration_avg_7d  = self._parse_avg_radon(value[11], value[12])["value"]
             self.radon_concentration_avg_30d = self._parse_avg_radon(value[13], value[14])["value"]
@@ -287,7 +309,7 @@ class CurrentReading:
             self.pressure = self._set(Param.PRESSURE, value[2])
             self.humidity = self._set(Param.HUMIDITY2, value[3])
             self.battery = value[5]
-            self.status = self.status = Status(value[6])
+            self.status = Color(value[6])
             self.interval = value[7]
             self.ago = value[8]
             self.counter = value[9]
@@ -308,23 +330,6 @@ class CurrentReading:
             "progress": progress
     }
 
-    @staticmethod
-    def _decode_status_flags(status):
-        status_t = Status.GREEN
-        status_h = Status.GREEN
-
-        if status & 0b0001:
-            status_h = Status.BLUE
-        elif status & 0b0010:
-            status_h = Status.RED
-
-        if status & 0b0100:
-            status_t = Status.BLUE
-        elif status & 0b1000:
-            status_t = Status.RED
-
-        return (status_h, status_t)
-
     @staticmethod
     def _set(param: Param, value: int):
         """
@@ -413,7 +418,7 @@ class ManufacturerData:
         self.version = Version(value[3], value[2], value[1])
 
     def _get_b(self, value, pos):
-        return True if value & (1 << pos) else False
+        return (value & (1 << pos)) != 0
 
     def _get_uint2(self, value, pos):
         return (value >> pos) & 0x03
@@ -433,7 +438,7 @@ class Aranet4Advertisement:
 
         if device and ad_data:
             has_manufacturer_data = Aranet4.MANUFACTURER_ID in ad_data.manufacturer_data
-            self.rssi = getattr(ad_data, 'rssi', None)
+            self.rssi = getattr(ad_data, "rssi", None)
 
             if has_manufacturer_data:
                 mf_data = ManufacturerData()
@@ -537,12 +542,12 @@ class SensorState:
     calibrationProgress: int = 0
     warningPreset: str = "unknown"
     isLoRaEnabled: bool = False
-    temperatureUnit: str = "unknwonw"
+    temperatureUnit: str = "unknown"
     isPulseBeepOn: bool = False
     isUsingCustomThreshold: bool = False
     isAutomaticCalibrationEnabled: bool = False
-    radiationDisplayUnits: str = "unknwon"
-    radonDisplayUnits: str = "unknwon"
+    radiationDisplayUnits: str = "unknown"
+    radonDisplayUnits: str = "unknown"
     isBuzzerAvailable: bool = False
     bluetoothRange: str = "unknown"
     isOpenForIntegration: bool = False
@@ -552,8 +557,8 @@ class SensorState:
         isAranet4 = t[0] == 0xF1 # Aranet4
         isNucleo  = t[0] == 0xF4 # Aranet Radiation
         isRadon   = t[0] == 0xF3 # Aranet Radon
-        c = format(ord(chr(t[1])), '08b')[::-1]
-        o = format(ord(chr(t[2])), '08b')[::-1]
+        c = format(ord(chr(t[1])), "08b")[::-1]
+        o = format(ord(chr(t[2])), "08b")[::-1]
 
         if isAranet4:
             self.type = AranetType.ARANET4
@@ -594,7 +599,7 @@ class SensorState:
 
     @staticmethod
     def parseCalibrationState(e):
-        t = format(ord(chr(e)), '08b')[::-1]
+        t = format(ord(chr(e)), "08b")[::-1]
         return SensorState.cond(
             t[3],
             SensorState.cond(t[2], "inErrorState", "endRequest"),
@@ -602,10 +607,10 @@ class SensorState:
         )
 
     @staticmethod
-    def cond(check, tru, fal):
+    def cond(check, true_condition, false_condition):
         if _eval(check):
-            return tru
-        return fal
+            return true_condition
+        return false_condition
 
 
 class HistoryHeader(NamedTuple):
@@ -626,49 +631,63 @@ class Aranet4:
     # Param return value if no data
     AR4_NO_DATA_FOR_PARAM = -1
 
-    # Manufacurer id
+    # Company Identifier (Akciju sabiedriba "SAF TEHNIKA")
     MANUFACTURER_ID = 0x0702
 
-    # Aranet UUIDs and handles
-    # Services
-    AR4_OLD_SERVICE = "f0cd1400-95da-4f4b-9ac8-aa55d312af0c" # until v1.2.0
-    AR4_SERVICE = "0000fce0-0000-1000-8000-00805f9b34fb" # v1.2.0 and later
-    GENERIC_SERVICE = "00001800-0000-1000-8000-00805f9b34fb"
-    COMMON_SERVICE = "0000180a-0000-1000-8000-00805f9b34fb"
+    # GAP Service
+    SERVICE_GAP = normalize_uuid_16(0x1800)
 
-    # Read / Aranet service
-    AR4_READ_CURRENT_READINGS = "f0cd1503-95da-4f4b-9ac8-aa55d312af0c"
-    AR4_READ_CURRENT_READINGS_DET = "f0cd3001-95da-4f4b-9ac8-aa55d312af0c"
-    AR2_READ_CURRENT_READINGS = "f0cd1504-95da-4f4b-9ac8-aa55d312af0c"
-    AR2_READ_CURRENT_READINGS_A = "f0cd3003-95da-4f4b-9ac8-aa55d312af0c" # data is same as other
-    # aranet2 has different service uids. use rhose
-    AR4_READ_INTERVAL = "f0cd2002-95da-4f4b-9ac8-aa55d312af0c"
-    AR4_READ_SECONDS_SINCE_UPDATE = "f0cd2004-95da-4f4b-9ac8-aa55d312af0c"
-    AR4_READ_TOTAL_READINGS = "f0cd2001-95da-4f4b-9ac8-aa55d312af0c"
-    AR4_READ_HISTORY_READINGS_V1 = "f0cd2003-95da-4f4b-9ac8-aa55d312af0c"
-    AR4_READ_HISTORY_READINGS_V2 = "f0cd2005-95da-4f4b-9ac8-aa55d312af0c"
-    AR4_READ_SENSOR_STATE = "f0cd1401-95da-4f4b-9ac8-aa55d312af0c"
+    # GAP Service Characteristics
+    CHARACTERISTIC_DEVICE_NAME = normalize_uuid_16(0x2a00)
+    CHARACTERISTIC_APPEARANCE = normalize_uuid_16(0x2a01)
 
+    # Device Information Service
+    SERVICE_DIS = normalize_uuid_16(0x180a)
 
-    # Read / Generic servce
-    GENERIC_READ_DEVICE_NAME = "00002a00-0000-1000-8000-00805f9b34fb"
+    # Device Information Service Characteristics 
+    CHARACTERISTIC_SYSTEM_ID = normalize_uuid_16(0x2a23)
+    CHARACTERISTIC_MODEL_NUMBER = normalize_uuid_16(0x2a24)
+    CHARACTERISTIC_SERIAL_NO = normalize_uuid_16(0x2a25)
+    CHARACTERISTIC_SW_REV = normalize_uuid_16(0x2a26)
+    CHARACTERISTIC_HW_REV = normalize_uuid_16(0x2a27)
+    CHARACTERISTIC_SW_REV_FACTORY = normalize_uuid_16(0x2a28)
+    CHARACTERISTIC_MANUFACTURER_NAME = normalize_uuid_16(0x2a29)
 
-    # Read / Common servce
-    COMMON_READ_MANUFACTURER_NAME = "00002a29-0000-1000-8000-00805f9b34fb"
-    COMMON_READ_MODEL_NUMBER = "00002a24-0000-1000-8000-00805f9b34fb"
-    COMMON_READ_SERIAL_NO = "00002a25-0000-1000-8000-00805f9b34fb"
-    COMMON_READ_HW_REV = "00002a27-0000-1000-8000-00805f9b34fb"
-    COMMON_READ_FACTORY_SW_REV = "00002a28-0000-1000-8000-00805f9b34fb"
-    COMMON_READ_SW_REV = "00002a26-0000-1000-8000-00805f9b34fb"
-    COMMON_READ_BATTERY = "00002a19-0000-1000-8000-00805f9b34fb"
+    # Battery Service
+    SERVICE_BATTERY = normalize_uuid_16(0x180f)
 
-    # Write / Aranet service
-    AR4_WRITE_CMD = "f0cd1402-95da-4f4b-9ac8-aa55d312af0c"
+    # Battery Service Characteristics
+    CHARACTERISTIC_BATTERY_LEVEL = normalize_uuid_16(0x2a19)
+
+    # SAF Tehnika Service
+    SERVICE_SAF_TEHNIKA = normalize_uuid_16(0xfce0) # v1.2.0 and later
+    SERVICE_SAF_TEHNIKA_OLD = "f0cd1400-95da-4f4b-9ac8-aa55d312af0c" # until v1.2.0
+
+    # SAF Tehnika Service Characteristics (Aranet2 has different readings characteristic uuids)
+    CHARACTERISTIC_SENSOR_STATE = "f0cd1401-95da-4f4b-9ac8-aa55d312af0c"
+    CHARACTERISTIC_CMD = "f0cd1402-95da-4f4b-9ac8-aa55d312af0c"
+    CHARACTERISTIC_CALIBRATION_DATA = "f0cd1502-95da-4f4b-9ac8-aa55d312af0c"
+    CHARACTERISTIC_CURRENT_READINGS = "f0cd1503-95da-4f4b-9ac8-aa55d312af0c"
+    CHARACTERISTIC_CURRENT_READINGS_AR2 = "f0cd1504-95da-4f4b-9ac8-aa55d312af0c" # Aranet2 Only
+    CHARACTERISTIC_TOTAL_READINGS = "f0cd2001-95da-4f4b-9ac8-aa55d312af0c"
+    CHARACTERISTIC_INTERVAL = "f0cd2002-95da-4f4b-9ac8-aa55d312af0c"
+    CHARACTERISTIC_HISTORY_READINGS_V1 = "f0cd2003-95da-4f4b-9ac8-aa55d312af0c"
+    CHARACTERISTIC_SECONDS_SINCE_UPDATE = "f0cd2004-95da-4f4b-9ac8-aa55d312af0c"
+    CHARACTERISTIC_HISTORY_READINGS_V2 = "f0cd2005-95da-4f4b-9ac8-aa55d312af0c"
+    CHARACTERISTIC_CURRENT_READINGS_DET = "f0cd3001-95da-4f4b-9ac8-aa55d312af0c"
+    CHARACTERISTIC_CURRENT_READINGS_A = "f0cd3002-95da-4f4b-9ac8-aa55d312af0c"
+    CHARACTERISTIC_CURRENT_READINGS_A_AR2 = "f0cd3003-95da-4f4b-9ac8-aa55d312af0c" # Aranet2 Only
+
+    # Nordic Semiconductor ASA Service
+    SERVICE_NORDIC_SEMICONDUCTOR = normalize_uuid_16(0xfe59)
+    
+    # Nordic Semiconductor ASA Service Characteristics
+    CHARACTERISTIC_SECURE_DFU = "8ec90003-f315-4f60-9fb8-838830daea50"
 
     # Regexp
     REGEX_MAC  = "([0-9a-f]{2}[:-]){5}([0-9a-f]{2})"
     REGEX_UUID = "[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}"
-    REGEX_ADDR = "({})|({})".format(REGEX_MAC, REGEX_UUID)
+    REGEX_ADDR = f"({REGEX_MAC})|({REGEX_UUID})"
 
     def __init__(self, address: str):
         if not re.match(self.REGEX_ADDR, address.lower()):
@@ -692,11 +711,11 @@ class Aranet4:
         readings = CurrentReading()
 
         new_aranet_char = self.device.services.get_characteristic(
-            self.AR2_READ_CURRENT_READINGS
+            self.CHARACTERISTIC_CURRENT_READINGS_AR2
         )
 
         if new_aranet_char:
-            uuid = self.AR2_READ_CURRENT_READINGS
+            uuid = self.CHARACTERISTIC_CURRENT_READINGS_AR2
             raw_bytes = await self.device.read_gatt_char(uuid)
 
             isRadon = raw_bytes[0] == 3
@@ -719,11 +738,11 @@ class Aranet4:
                 readings.decode(value, AranetType.ARANET2, True)
         else:
             if details:
-                uuid = self.AR4_READ_CURRENT_READINGS_DET
+                uuid = self.CHARACTERISTIC_CURRENT_READINGS_DET
                 # co2, temp, pressure, humidity, battery, status
                 value_fmt = "<HHHBBBHH"
             else:
-                uuid = self.AR4_READ_CURRENT_READINGS
+                uuid = self.CHARACTERISTIC_CURRENT_READINGS
                 # co2, temp, pressure, humidity, battery, status, interval, ^
                 value_fmt = "<HHHBBB"
 
@@ -734,22 +753,22 @@ class Aranet4:
 
     async def get_interval(self) -> int:
         """Get the value for how often datapoints are logged on device"""
-        raw_bytes = await self.device.read_gatt_char(self.AR4_READ_INTERVAL)
+        raw_bytes = await self.device.read_gatt_char(self.CHARACTERISTIC_INTERVAL)
         return int.from_bytes(raw_bytes, byteorder="little")
 
     async def get_name(self):
         """Get name of remote device"""
         try:
-            raw_bytes = await self.device.read_gatt_char(self.GENERIC_READ_DEVICE_NAME)
+            raw_bytes = await self.device.read_gatt_char(self.CHARACTERISTIC_DEVICE_NAME)
             return raw_bytes.decode("utf-8")
         except:
             # fallback to serial number
-            raw_bytes = await self.device.read_gatt_char(self.COMMON_READ_SERIAL_NO)
+            raw_bytes = await self.device.read_gatt_char(self.CHARACTERISTIC_SERIAL_NO)
             return "Aranet4 {}".format(raw_bytes.decode("utf-8"))
 
     async def get_version(self):
         """Get firmware version of remote device"""
-        raw_bytes = await self.device.read_gatt_char(self.COMMON_READ_SW_REV)
+        raw_bytes = await self.device.read_gatt_char(self.CHARACTERISTIC_SW_REV)
         return raw_bytes.decode("utf-8")
 
     async def get_seconds_since_update(self):
@@ -757,12 +776,12 @@ class Aranet4:
         Get the value for how long (in seconds) has passed since last
         datapoint was logged
         """
-        raw_bytes = await self.device.read_gatt_char(self.AR4_READ_SECONDS_SINCE_UPDATE)
+        raw_bytes = await self.device.read_gatt_char(self.CHARACTERISTIC_SECONDS_SINCE_UPDATE)
         return int.from_bytes(raw_bytes, byteorder="little")
 
     async def get_total_readings(self):
         """Return the count of how many datapoints are logged on device"""
-        raw_bytes = await self.device.read_gatt_char(self.AR4_READ_TOTAL_READINGS)
+        raw_bytes = await self.device.read_gatt_char(self.CHARACTERISTIC_TOTAL_READINGS)
         return int.from_bytes(raw_bytes, byteorder="little")
 
     async def get_last_measurement_date(self, use_epoch: bool = False):
@@ -785,7 +804,7 @@ class Aranet4:
         """
 
         history_v2 = self.device.services.get_characteristic(
-            self.AR4_READ_HISTORY_READINGS_V2
+            self.CHARACTERISTIC_HISTORY_READINGS_V2
         )
 
         if history_v2 is not None:
@@ -801,24 +820,23 @@ class Aranet4:
         List will be length of "total datapoints". If index is outside `start`
         and `end` request then default of `-1` is returned for those datapoints.
         """
-        if start < 1:
-            start = 0x0001
+        start = max(start, 0x0001)
 
         header = 0x61
         val = struct.pack("<BBH", header, param.value, start)
-        # Request command: b'\x61\x01\x01\x00'
+        # Request command: b"\x61\x01\x01\x00"
         # for temperature from start at 1
-        # Request command: b'\x61\x04\xde\x01'
+        # Request command: b"\x61\x04\xde\x01"
         # for co2 from start at 478
 
         result = _empty_reading(log_size)
 
-        await self.device.write_gatt_char(self.AR4_WRITE_CMD, val, True)
+        await self.device.write_gatt_char(self.CHARACTERISTIC_CMD, val, True)
 
         reading = True
         while reading:
             packet = await self.device.read_gatt_char(
-                self.AR4_READ_HISTORY_READINGS_V2
+                self.CHARACTERISTIC_HISTORY_READINGS_V2
             )
 
             header = HistoryHeader(*struct.unpack("<BHHHHB", packet[:10]))
@@ -865,37 +883,36 @@ class Aranet4:
         List will be length of "total datapoints". If index is outside `start`
         and `end` request then default of `-1` is returned for those datapoints.
         """
-        if start < 1:
-            start = 0x0001
+        start = max(start, 0x0001)
 
         header = 0x82
         unknown = 0x00
         val = struct.pack("<BBHHH", header, param.value, unknown, start, end)
-        # Request command: b'\x82\x01\x00\x00\x01\x00\xe0\x07'
+        # Request command: b"\x82\x01\x00\x00\x01\x00\xe0\x07"
         # for temperature from start at 1 and ending 2016
-        # Request command: b'\x82\x04\x00\x00\xde\x01\x3d\x05'
+        # Request command: b"\x82\x04\x00\x00\xde\x01\x3d\x05"
         # for co2 from start at 478 and end 1341
 
         # register delegate
         delegate = Aranet4HistoryDelegate(
-            self.AR4_READ_HISTORY_READINGS_V1, param, log_size, self
+            self.CHARACTERISTIC_HISTORY_READINGS_V1, param, log_size, self
         )
 
-        value = await self.device.write_gatt_char(self.AR4_WRITE_CMD, val, True)
+        await self.device.write_gatt_char(self.CHARACTERISTIC_CMD, val, True)
         self.reading = True
         await self.device.start_notify(
-            self.AR4_READ_HISTORY_READINGS_V1, delegate.handle_notification
+            self.CHARACTERISTIC_HISTORY_READINGS_V1, delegate.handle_notification
         )
         while self.reading:
             await asyncio.sleep(0.1)
-        await self.device.stop_notify(self.AR4_READ_HISTORY_READINGS_V1)
+        await self.device.stop_notify(self.CHARACTERISTIC_HISTORY_READINGS_V1)
         return delegate.result
 
     async def set_readings_interval(self, interval: int, verify: bool=True):
         """Set reading interval"""
         header = 0x90
         val = struct.pack("<BB", header, interval)
-        await self.device.write_gatt_char(self.AR4_WRITE_CMD, val, True)
+        await self.device.write_gatt_char(self.CHARACTERISTIC_CMD, val, True)
         if verify:
             iv = await self.get_interval()
             return interval == (iv / 60)
@@ -908,7 +925,7 @@ class Aranet4:
         """
         header = 0x91
         val = struct.pack("<BB", header, 1 if enabled else 0)
-        await self.device.write_gatt_char(self.AR4_WRITE_CMD, val, True)
+        await self.device.write_gatt_char(self.CHARACTERISTIC_CMD, val, True)
         if verify:
             state = await self.get_sensor_state()
             return enabled == state.isOpenForIntegration
@@ -918,17 +935,16 @@ class Aranet4:
         """Set bluetooth range"""
         header = 0x92
         val = struct.pack("<BB", header, 1 if extended else 0)
-        await self.device.write_gatt_char(self.AR4_WRITE_CMD, val, True)
+        await self.device.write_gatt_char(self.CHARACTERISTIC_CMD, val, True)
         if verify:
             state = await self.get_sensor_state()
             if extended:
                 return state.bluetoothRange == "extended"
-            else:
-                return state.bluetoothRange == "normal"
+            return state.bluetoothRange == "normal"
 
     async def get_sensor_state(self):
         """Return the count of how many datapoints are logged on device"""
-        raw_bytes = await self.device.read_gatt_char(self.AR4_READ_SENSOR_STATE)
+        raw_bytes = await self.device.read_gatt_char(self.CHARACTERISTIC_SENSOR_STATE)
         state = SensorState()
         state.decode(raw_bytes)
         return state
@@ -1001,7 +1017,7 @@ async def _current_reading(address):
     return readings
 
 def _eval(val) -> bool:
-    falsy = ['0', 'false', 'disable', 'disabled', 'no', 'off', "none"]
+    falsy = ["0", "false", "disable", "disabled", "no", "off", "none"]
     if isinstance(val, str):
         return val.lower() not in falsy
     return bool(val)
@@ -1012,19 +1028,19 @@ async def _set_settings(address, settings, verify: bool=True) -> dict:
     await monitor.connect()
     status = {}
 
-    if 'interval' in settings:
-        intval = int(settings['interval'])
-        status['interval'] = await monitor.set_readings_interval(intval, verify)
+    if "interval" in settings:
+        intval = int(settings["interval"])
+        status["interval"] = await monitor.set_readings_interval(intval, verify)
 
-    if 'range' in settings:
-        extend = ['extend', 'extended', '1']
-        extend = settings['range'].lower() in extend
-        status['range'] = await monitor.set_bluetooth_range(extend, verify)
+    if "range" in settings:
+        extend = ["extend", "extended", "1"]
+        extend = settings["range"].lower() in extend
+        status["range"] = await monitor.set_bluetooth_range(extend, verify)
 
-    if 'integrations' in settings:
-        on = ['on', 'enable', 'enabled', '1']
-        on = settings['integrations'].lower() in on
-        status['integrations'] = await monitor.set_home_integration_enabled(on, verify)
+    if "integrations" in settings:
+        on = ["on", "enable", "enabled", "1"]
+        on = settings["integrations"].lower() in on
+        status["integrations"] = await monitor.set_home_integration_enabled(on, verify)
 
     return status
 
@@ -1046,7 +1062,7 @@ class Aranet4Scanner:
         self.on_scan(adv)
 
     def __init__(self, on_scan):
-        uuids = [Aranet4.AR4_SERVICE, Aranet4.AR4_OLD_SERVICE]
+        uuids = [Aranet4.SERVICE_SAF_TEHNIKA, Aranet4.SERVICE_SAF_TEHNIKA_OLD]
         self.on_scan = on_scan
         self.scanner = BleakScanner(
             detection_callback=self._process_advertisement,
@@ -1072,7 +1088,7 @@ async def _find_nearby(detect_callback: callable, duration: int) -> List[BLEDevi
 def find_nearby(detect_callback: callable, duration: int = 5) -> List[BLEDevice]:
     """
     Scans for nearby Aranet4 devices.
-    Will call callback on every valid Aranet4 advertisement, including duplcates
+    Will call callback on every valid Aranet4 advertisement, including duplicates
     """
 
     return asyncio.run(_find_nearby(detect_callback, duration))
@@ -1100,7 +1116,7 @@ async def _all_records(address, entry_filter, remove_empty):
     interval = await monitor.get_interval()
     next_log = interval - last_log
     # Decide if there is enough time to read all the data
-    # before the next datapoint in logged.
+    # before the next datapoint is logged.
     print(f"Next data point will be logged in {next_log} seconds")
     if next_log < 10:
         print(f"Waiting {next_log} for next datapoint to be taken...")
@@ -1148,7 +1164,7 @@ async def _all_records(address, entry_filter, remove_empty):
 
     if begin < 0 or end < 0:
         # invalid range. Most likely no points available
-        return  Record(dev_name, dev_version, log_size, rec_filter)
+        return Record(dev_name, dev_version, log_size, rec_filter)
 
     # Read datapoint history from device
     if rec_filter.incl_temperature:
@@ -1221,7 +1237,7 @@ async def _all_records(address, entry_filter, remove_empty):
 
     for date, co2, temp, pres, hum, rad, rad_rate, rad_integral, radon in data:
         record.value.append(RecordItem(date, temp, hum, pres, co2, rad, rad_rate, rad_integral, radon))
-    if (remove_empty):
+    if remove_empty:
         record.value = record.value[begin-1:end+1]
     return record
 
