@@ -1,8 +1,8 @@
-import aranet4
-import datetime
 import csv
 
-# aranet4 mac address
+import aranet4
+
+# Aranet4 MAC address
 device_mac = "XX:XX:XX:XX:XX:XX"
 
 # Selection filter. Will export last 25 records
@@ -17,9 +17,9 @@ records = aranet4.client.get_all_records(
     remove_empty=True # This will remove blank records, if range parameters (start,end,last) are specified
 )
 
-# write CSV file
-with open('aranet_history.csv', 'w') as file:
-    writer = csv.writer(file)
+# Write CSV file
+with open(file="aranet_history.csv", mode="w", encoding="utf-8") as csv_file:
+    writer = csv.writer(csv_file)
 
     header = [
         "date",
